using BPA.SAAS.Manage.Application.DataBase.Dtos.GoodsEnergyConfig;
using BPA.SAAS.Manage.Core.Base;
using BPA.SAAS.Manage.Core.DataBase;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.DataBase.Interface
{
    public interface IGoodsEnergyConfigService
    {
        /// <summary>
        /// 分页查询
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<PageUtil> GetGoodsEnergyConfigPage(GoodsEnergyConfigQueryDto dto);
        /// <summary>
        /// 添加
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<bool> AddGoodsEnergyConfig(GoodsEnergyConfigDto dto);
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<bool> UpdateGoodsEnergyConfig(GoodsEnergyConfigDto dto);
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        Task<bool> DelGoodsEnergyConfig(string Id);
        /// <summary>
        /// 查询详情
        /// </summary>
        /// <param name="goodsenergyconfigId"></param>
        /// <returns></returns>
        Task<List<GoodsEnergyConfigDetailsViewDto>> GetGoodsEnergyConfigDetailsList(string goodsenergyconfigId);
        /// <summary>
        /// 添加
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<bool> AddGoodsEnergyConfigDetails(GoodsEnergyConfigDetailsDto dto);
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<bool> UpdateGoodsEnergyConfigDetails(GoodsEnergyConfigDetailsDto dto);
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
        Task<bool> DelGoodsEnergyConfigDetails(string Id);
    }
}
